@@ -28,6 +28,7 @@ Software by: MVTec Software GmbH, www.mvtec.com
 """
 
 import ctypes
+import os
 import sys
 
 from typing import Sequence, Final, Union, Optional, Dict, cast
@@ -40,6 +41,7 @@ from .meta import halcon_native_lib_names
 
 __all__ = [
     'get_sem_type',
+    'H_MSG_OK',
     'HalconOperator',
     'HCkP',
     'Herror',
@@ -52,6 +54,7 @@ __all__ = [
     'HTupleConversionError',
     'HTupleElementType',
     'HTupleType',
+    'make_c_func_prototype',
 ]
 
 
@@ -119,6 +122,9 @@ Herror = ctypes.c_uint32
 # the value on Python side. c_void_p is simpler than byref(c_long).
 Hkey = ctypes.c_void_p
 
+# TODO automatic constant and error code generation.
+H_MSG_OK = 2
+
 
 class HObjectBase(object):
     """
@@ -356,7 +362,7 @@ def load_native_lib(names: Dict[str, str]) -> ctypes.CDLL:
         name = names['linux']
     elif sys.platform.startswith('darwin'):
         name = names['darwin']
-    elif sys.platform == 'win32' or sys.plaform == 'cygwin':
+    elif sys.platform == 'win32' or sys.platform == 'cygwin':
         name = names['win']
     else:
         raise HError(f'Unsupported operating system {sys.platform}')
@@ -376,8 +382,17 @@ def load_native_lib(names: Dict[str, str]) -> ctypes.CDLL:
 
     return lib
 
+
+def make_c_func_prototype(restype, *argtypes):
+    if _is_32bit_win:
+        return ctypes.WINFUNCTYPE(restype, *argtypes)
+
+    return ctypes.CFUNCTYPE(restype, *argtypes)
+
+
 # --- Private Implementation Details ---
 
+_is_32bit_win = os.name == 'nt' and sys.maxsize == (2**31 - 1)
 
 # Load dynamic HALCON library.
 _halcon_lib: Final[ctypes.CDLL] = load_native_lib(halcon_native_lib_names)
